@@ -1,6 +1,6 @@
 package Map::Tube::CLI;
 
-$Map::Tube::CLI::VERSION   = '0.30';
+$Map::Tube::CLI::VERSION   = '0.31';
 $Map::Tube::CLI::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::CLI - Command Line Interface for Map::Tube::* map.
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
@@ -120,6 +120,8 @@ sure you have the latest maps when you install.
 
 =item * L<KoelnBonn|Map::Tube::KoelnBonn>
 
+=item * L<Kolkatta|Map::Tube::Kolkatta>
+
 =item * L<KualaLumpur|Map::Tube::KualaLumpur>
 
 =item * L<London|Map::Tube::London>
@@ -323,6 +325,7 @@ sub _supported_maps {
         'KHARKIV'         => 'Map::Tube::Kharkiv',
         'KIEV'            => 'Map::Tube::Kiev',
         'KOELNBONN'       => 'Map::Tube::KoelnBonn',
+        'KOLKATTA'        => 'Map::Tube::Kolkatta',
         'KUALALUMPUR'     => 'Map::Tube::KualaLumpur',
         'LONDON'          => 'Map::Tube::London',
         'LYON'            => 'Map::Tube::Lyon',
